@@ -2,7 +2,7 @@
 
 calc_nls <- function(pars, time, obs, model_out, ...) {
 
-  if(is.vector(time)) {
+  if(!is.list(time)) {
     sum(unlist(lapply(names(obs),function(var)
       (model_out[,var] - obs[[var]])^2)))
   }
@@ -37,7 +37,7 @@ calc_nll_normal <- function(pars, time, obs, model_out, sigma_name, ...) {
     time_ode <- model_out[,1]
     -sum(unlist(lapply(names(obs),function(var) {
       stats::dnorm(obs[[var]],mean=model_out[which(time_ode %in% time[[var]]),var],
-            sd=sigma,log=T)
+                   sd=sigma,log=T)
     })))
   }
 }
@@ -80,12 +80,12 @@ calc_nll_normal <- function(pars, time, obs, model_out, sigma_name, ...) {
 # @return The integral-matching loss value
 #
 calc_im_loss <- function(pars, equations, x0, time, obs,
-                  im_method=c("separable","non-separable"),
-                  lin_pars_names, lin_pars_min=NULL, lin_pars_max=NULL,
-                  pars_min=NULL, pars_max=NULL, gen_obs=NULL, scale_pars=NULL,
-                  pars2vars=NULL, im_smoothing=c('splines','kernel','none'),
-                  im_grid_size=0, bw_factor=1.5,
-                  trace=0, save_im_trace=F, simode_env=emptyenv(), ...)
+                         im_method=c("separable","non-separable"),
+                         lin_pars_names, lin_pars_min=NULL, lin_pars_max=NULL,
+                         pars_min=NULL, pars_max=NULL, gen_obs=NULL, scale_pars=NULL,
+                         pars2vars=NULL, im_smoothing=c('splines','kernel','none'),
+                         im_grid_size=0, bw_factor=1.5,
+                         trace=0, save_im_trace=F, simode_env=emptyenv(), ...)
 {
   im_method <- match.arg(im_method)
 
@@ -136,12 +136,12 @@ calc_im_loss <- function(pars, equations, x0, time, obs,
   im_fit <- NULL
   tryCatch( {
     im_fit <- simode_fit(equations=equations, pars=lin_pars_names, time=time, obs=obs, x0=x0,
-               pars_min=lin_pars_min, pars_max=lin_pars_max,
-               im_smoothing=im_smoothing, im_grid_size=im_grid_size, bw_factor=bw_factor,
-               vars2update=vars2update, im_fit_prev=simode_env$im, trace=trace)
-    },
-    warning = function(w) { if(trace>2) print(w) },
-    error = function(e) { if(trace>1) print(e) }
+                         pars_min=lin_pars_min, pars_max=lin_pars_max,
+                         im_smoothing=im_smoothing, im_grid_size=im_grid_size, bw_factor=bw_factor,
+                         vars2update=vars2update, im_fit_prev=simode_env$im, trace=trace)
+  },
+  warning = function(w) { if(trace>2) print(w) },
+  error = function(e) { if(trace>1) print(e) }
   )
 
   if(is.null(im_fit)) {
@@ -208,10 +208,10 @@ calc_im_loss <- function(pars, equations, x0, time, obs,
 # @return The nonlinear least squares loss value
 #
 calc_nls_loss <- function(pars, equations, x0, time, obs,
-                        pars_min=NULL, pars_max=NULL,
-                        fixed=NULL, calc_nll=calc_nls, scale_pars=NULL,
-                        trace=0, save_nls_trace=F, ode_control=NULL,
-                        simode_env=emptyenv(), ...)
+                          pars_min=NULL, pars_max=NULL,
+                          fixed=NULL, calc_nll=calc_nls, scale_pars=NULL,
+                          trace=0, save_nls_trace=F, ode_control=NULL,
+                          simode_env=emptyenv(), ...)
 {
 
   if(!is.null(pars_min)) {
@@ -235,7 +235,7 @@ calc_nls_loss <- function(pars, equations, x0, time, obs,
 
   time_ode <- time
   if(is.list(time)) {
-    time_model <- sort(unique(unlist(time)))
+    time_ode <- sort(unique(unlist(time)))
     names(time) <- names(obs)
   }
 
